Architecture Overview
=====================

Wasabi Scenegraph is designed to present to users a high-level API that allows
complex 3D scenes to be composed easily in Python code.

However it is also designed to have an easily extensible component model behind
the scenes that connects the high-level API to OpenGL and the graphics
hardware.

